import hasValidContext from './utils/hasValidContext';
import threadScheduler from './ThreadScheduler';
/**
 * Waits for the browser to become idle again in order to resume work. Calling `yieldControl()`
 * multiple times will create a LIFO(last in, first out) queue – the last call to
 * `yieldControl()` will get resolved first.
 *
 * @param strategy {SchedulingStrategy} The priority of the task being run.
 * `smooth` priority will always be resolved first. `background` priority will always be
 * resolved second.
 * @returns {Promise<void>} A promise that gets resolved when the work can continue.
 */
export default async function yieldControl(strategy = 'smooth') {
    if (!hasValidContext()) {
        return;
    }
    const task = threadScheduler.createTask(strategy);
    return task.promise;
}
